@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.spamhandler.defaultspamhandler;
 
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.service.MailService;
@@ -62,6 +63,11 @@ import com.openexchange.spamhandler.SpamHandler;
  */
 public final class DefaultSpamHandler extends SpamHandler {
 
+    /**
+     * The configuration service supplier.
+     */
+    private static final ConfigurationServiceSupplier SUPPLIER = ConfigurationServiceSupplier.getInstance();
+
     private static final String NAME = "DefaultSpamHandler";
 
     private static final DefaultSpamHandler instance = new DefaultSpamHandler();
@@ -109,4 +115,40 @@ public final class DefaultSpamHandler extends SpamHandler {
         }
     }
 
+    @Override
+    public boolean isCreateConfirmedSpam() {
+        final ConfigurationService configurationService = SUPPLIER.getConfigurationService();
+        if (null == configurationService) {
+            /*
+             * Return default
+             */
+            return true;
+        }
+        return configurationService.getBoolProperty("com.openexchange.spamhandler.defaultspamhandler.createConfirmedSpam", true);
+    }
+
+    @Override
+    public boolean isCreateConfirmedHam() {
+        final ConfigurationService configurationService = SUPPLIER.getConfigurationService();
+        if (null == configurationService) {
+            /*
+             * Return default
+             */
+            return true;
+        }
+        return configurationService.getBoolProperty("com.openexchange.spamhandler.defaultspamhandler.createConfirmedHam", true);
+    }
+
+    @Override
+    public boolean isUnsubscribeSpamFolders() {
+        final ConfigurationService configurationService = SUPPLIER.getConfigurationService();
+        if (null == configurationService) {
+            /*
+             * Return default
+             */
+            return true;
+        }
+        return configurationService.getBoolProperty("com.openexchange.spamhandler.defaultspamhandler.unsubscribeSpamFolders", true);
+    }
+
 }
